import _extends from "@babel/runtime/helpers/esm/extends";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import _objectWithoutProperties from "@babel/runtime/helpers/esm/objectWithoutProperties";
var _excluded = ["conf", "convertValueToDisplay", "convertValueFromDisplay", "minLines", "maxLines", "value", "onChange"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) { symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); } keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import _forEach from 'lodash/forEach';
import React, { useRef, useState, useCallback, useEffect } from 'react';
import createEditor from '../../util/create-editor';
import computeScrollHeight from '../../util/compute-scroll-height';
import Wrapper from './wrapper';

function convertValue(displayValue, convert) {
  return convert ? convert(displayValue) || '' : displayValue;
}

function usePrevious(value) {
  var ref = useRef(null);
  useEffect(function () {
    ref.current = value;
  });
  return ref.current;
}
/**
 * CodeMirror
 */


export default function CodeMirror(_ref) {
  var conf = _ref.conf,
      convertValueToDisplay = _ref.convertValueToDisplay,
      convertValueFromDisplay = _ref.convertValueFromDisplay,
      _ref$minLines = _ref.minLines,
      minLines = _ref$minLines === void 0 ? 6 : _ref$minLines,
      _ref$maxLines = _ref.maxLines,
      maxLines = _ref$maxLines === void 0 ? 30 : _ref$maxLines,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? '' : _ref$value,
      onChange = _ref.onChange,
      props = _objectWithoutProperties(_ref, _excluded);

  var refWrapper = useRef(null);

  var _useState = useState(convertValue(value, convertValueToDisplay)),
      _useState2 = _slicedToArray(_useState, 2),
      stateDisplayValue = _useState2[0],
      setStateDisplayValue = _useState2[1];

  var _useState3 = useState(null),
      _useState4 = _slicedToArray(_useState3, 2),
      stateEditor = _useState4[0],
      setStateEditor = _useState4[1];

  var prevValue = usePrevious(value);
  var handleChange = useCallback(function (editor) {
    var newValue = editor.getValue();
    setStateDisplayValue(newValue);

    if (onChange) {
      onChange(convertValue(newValue, convertValueFromDisplay));
    }
  }, [convertValueFromDisplay, onChange]);
  useEffect(function () {
    if (!refWrapper.current || stateEditor) {
      return;
    }

    var editor = createEditor(refWrapper.current, stateDisplayValue, conf);
    editor.on('change', handleChange);

    _forEach(conf === null || conf === void 0 ? void 0 : conf.on, function (fn, k) {
      return editor.on(k, fn);
    });

    setStateEditor(editor);
  }, [conf, stateEditor, stateDisplayValue, setStateEditor, handleChange]);
  useEffect(function () {
    if (!stateEditor) {
      return;
    }

    var newDisplayValue = convertValue(value, convertValueToDisplay);

    if (prevValue !== value && stateDisplayValue !== newDisplayValue) {
      setStateDisplayValue(newDisplayValue);
      stateEditor.setValue(newDisplayValue);
    }
  }, [prevValue, value, stateDisplayValue, convertValueToDisplay, stateEditor]);
  return /*#__PURE__*/React.createElement(Wrapper, _extends({
    ref: refWrapper
  }, _objectSpread(_objectSpread({}, props), {}, {
    minHeight: computeScrollHeight(minLines),
    maxHeight: computeScrollHeight(maxLines)
  })));
}